summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-03 22:46:21 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-03 22:46:21 -0600
commitbd608b63a8654863e86960e8f2301eac012aa44d (patch)
treeb6afbfd54a25b4d835e9de1c6d3eb1366b2255f5 /src
parent888390be013f27d687f1f3ca6b5b9aec2c86c9f3 (diff)
downloadbasket-bd608b63a8654863e86960e8f2301eac012aa44d.tar.gz
basket-bd608b63a8654863e86960e8f2301eac012aa44d.zip
Rename KStyle to TDEStyle to avoid conflicts with KDE4
Diffstat (limited to 'src')
-rw-r--r--src/note.cpp6
-rw-r--r--src/tag.cpp2
2 files changed, 4 insertions, 4 deletions
diff --git a/src/tag.cpp b/src/tag.cpp
index 27327d1..7d6e657 100644
--- a/src/tag.cpp
+++ b/src/tag.cpp
@@ -855,7 +855,7 @@ TQIconSet StateMenuItem::checkBoxIconSet(bool checked, TQColorGroup cg)
int height = kapp->style().pixelMetric(TQStyle::PM_IndicatorHeight, 0);
TQRect rect(0, 0, width, height);
- TQColor menuBackgroundColor = (dynamic_cast<KStyle*>(&(kapp->style())) == NULL ? TQColor(cg.background()) : cg.background().light(103));
+ TQColor menuBackgroundColor = (dynamic_cast<TDEStyle*>(&(kapp->style())) == NULL ? TQColor(cg.background()) : cg.background().light(103));
// Enabled, Not hovering
TQPixmap pixmap(width, height);
diff --git a/src/note.cpp b/src/note.cpp
index abc72dd..9b94bc9 100644
--- a/src/note.cpp
+++ b/src/note.cpp
@@ -1281,8 +1281,8 @@ void drawGradient( TQPainter *p, const TQColor &colorTop, const TQColor & colorB
void Note::drawExpander(TQPainter *painter, int x, int y, const TQColor &background, bool expand, Basket *basket)
{
- // If the current style is a KStyle, use it to draw the expander (plus or minus):
- if (dynamic_cast<KStyle*>(&(kapp->style())) != NULL) {
+ // If the current style is a TDEStyle, use it to draw the expander (plus or minus):
+ if (dynamic_cast<TDEStyle*>(&(kapp->style())) != NULL) {
// Set the 4 rounded corners background to background color:
TQColorGroup cg(basket->colorGroup());
cg.setColor(TQColorGroup::Base, background);
@@ -1292,7 +1292,7 @@ void Note::drawExpander(TQPainter *painter, int x, int y, const TQColor &backgro
painter->fillRect(x, y, 9, 9, brush);
// Draw it:
- ((KStyle&)(kapp->style())).drawKStylePrimitive( KStyle::KPE_ListViewExpander,
+ ((TDEStyle&)(kapp->style())).drawTDEStylePrimitive( TDEStyle::KPE_ListViewExpander,
painter,
basket->viewport(),
TQRect(x, y, 9, 9),